/*
// $Id: //guest/julian_hyde/saffron/src/main/saffron/runtime/CompoundIterator.java#1 $
// Saffron preprocessor and data engine
// Copyright (C) 2002 Julian Hyde <julian.hyde@mail.com>
//
// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Library General Public
// License as published by the Free Software Foundation; either
// version 2 of the License, or (at your option) any later version.
//
// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Library General Public License for more details.
//
// You should have received a copy of the GNU Library General Public
// License along with this library; if not, write to the
// Free Software Foundation, Inc., 59 Temple Place - Suite 330,
// Boston, MA  02111-1307, USA.
//
// See the COPYING file located in the top-level-directory of
// the archive of this library for complete text of license.
//
// jhyde, May 1, 2002
*/

package saffron.runtime;

import java.util.Iterator;
import java.util.Collections;

/**
 * <code>CompoundIterator</code> creates an iterator out of several.
 */
public class CompoundIterator implements Iterator {
	private Iterator[] iterators;
	private int i;
	private Iterator iterator;

	public CompoundIterator(Iterator[] iterators) {
		this.iterators = iterators;
		this.i = 0;
		nextIterator();
	}
	private void nextIterator() {
		while (i < iterators.length) {
			iterator = iterators[i++];
			if (iterator.hasNext()) {
				return;
			}
		}
		iterator = Collections.EMPTY_LIST.iterator();
	}
	public boolean hasNext() {
		return iterator.hasNext();
	}
	public Object next() {
		Object o = iterator.next();
		if (!iterator.hasNext()) {
			nextIterator();
		}
		return o;
	}
	public void remove() {
		iterator.remove();
	}
}

// End CompoundIterator.java
